@@ -1,8 +1,8 @@
-from typing import Tuple, Optional
-import os
-import sys
 import argparse
 import asyncio
+import os
+import sys
+from typing import Optional, Tuple
 
 import urwid
 
@@ -68,6 +68,7 @@ def run(argv) -> None:
 
     palette = [
         ("text", "white", "black", ""),
+        ("edit", "black", "yellow", ""),
         ("btn focus", "white", "dark red", ""),
         ("btn normal", "white", "dark blue", ""),
         ("li normal", "light cyan", "black", ""),
@@ -87,6 +88,13 @@ def run(argv) -> None:
         ("remark", "dark gray", "black", ""),
         ("highlight", "yellow", "black", ""),
         ("topbar", "black", "white", ""),
+        # Toggles
+        ("disabled", "light red", "black", ""),
+        ("enabled", "light green", "black", ""),
+        # Strengths
+        ("str weak", "light red", "black", ""),
+        ("str average", "yellow", "black", ""),
+        ("str good", "light green", "black", ""),
         # Indicator color scheme
         ("ind normal", "black", "white", ""),
         ("ind error", "dark red", "white", ""),
